==> bruno-2.0.0.tar.gz: README.en-US.md <==


<p align="center">
  <a href="https://bruno.ke.com">
    <img width="200" src="https://img.ljcdn.com/beike/zjz/bruno/img/1637306783951.jpg">
  </a>
</p>



<h1 align="center">Bruno</h1>
<div align="center">

An enterprise-class package of Flutter components for mobile applications.

[![license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/LianjiaTech/bruno/blob/master/LICENSE)

</div>

<div align="center">

 [简体中文](./README.md) | English

</div>



![](https://img.ljcdn.com/beike/zjz/bruno/img/1637308027692.png)

## ✨ Features

* Enterprise-class UI designed for mobile applications.
* A set of high-quality Flutter components out of the box.
* Provides the ability to customize theme for different businesses
* Design tools to improve the efficiency of all participants

### Demo download

[Bruno for Android]()

[Bruno  for iOS]()


## Adapted version of Flutter


| Bruno Version | Flutter SDK Version |
| ---------- | ---------------- |
| 1.0.0      | 1.22.4           |
| 2.0.0      | 2.2.2            |



## Preparing for use

Add the following dependencies to the `pubspec.yaml` file:

```dart
dependencies:
  bruno: version
```

## Simple usage

```dart
import 'package:bruno/bruno.dart';
...
BrnBubbleText(
  maxLines: 3,
  text: 'I am first bubble text',
)
```

### 🌈 Customize themes

Reference [custom theme] ().



## Contributing

Please read our [Contributing]() first.

Thanks to all the developers who contributed to Bruno !

<div style="display:flex;flex-wrap: wrap;">
  <a href="https://github.com/violinday">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664602.png' />
  </a>
  <a href="https://github.com/zhoujuanjuan">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664928.png' />
  </a>
  <a href="https://github.com/hexintao">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664290.png' />
  </a>
  <a href="https://github.com/ShzMinato">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664590.png'  />
  </a>
  <a href="https://github.com/Nayuta403">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664273.png' />
  </a>
  <a href="https://github.com/liroya2003">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637736846398.png' />
  </a>
  <a href="https://github.com/lifuqing">
      <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664429.png' />
  </a>
  <a href="https://github.com/visitorvisit">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664282.png'  />
  </a>
  <a href="https://github.com/DNACore">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664426.png' />
  </a>
  <a href="https://github.com/SlamDunk007">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664914.png' />
  </a>
  <a href="https://github.com/zadouyoune">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664629.png' />
  </a>
  <a href="https://github.com/quanGitHub1">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664641.png'  />
  </a>
  <a href="https://github.com/bill19">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664536.png' />
  </a>
  <a href="https://github.com/MichaelWon">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664633.png' />
  </a>
  <a href="https://github.com/laoshubuluo">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664320.png' />
  </a>
  <a href="https://github.com/eason-lz">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664460.png' />
  </a>
  <a href="https://github.com/coolsining">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664465.png'  />
  </a>
  <a href="https://github.com/765227120">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637740374486.png' />
  </a>
  <a href="https://github.com/xzj524">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664906.png' />
  </a>
  </div>



## 🔗 Links

- [Homepage]()
- [All component ]()
- [Design concept]()
- [Preparing for use ]()
- [Customize themes]()
- [Frequently asked question]()
- [Sketch usage]()
- [Download of Design]()

## Acknowledgements

As a complete set of standard components, Bruno references the open source packages:

- [flutter_gifimage](https://github.com/peng8350/flutter_gifimage)
- [expansion_tile_card.dart](https://gist.github.com/Skylled/7ac0f2f99881f7df2a0a850e60ef2df0)
- [photo_view](https://github.com/bluefireteam/photo_view)
- [flutter_intro](https://github.com/tal-tech/flutter_intro)
- [flutter_badges](https://github.com/yako-dev/flutter_badges)
- [lpinyin](https://github.com/flutterchina/lpinyin)
- [azlistview](https://github.com/flutterchina/azlistview)
- [flutter_path_drawing](https://github.com/dnfield/flutter_path_drawing)

Thanks to the authors above.

==> bruno-2.2.0.tar.gz: README.en-US.md <==


<p align="center">
  <a href="https://bruno.ke.com">
    <img width="200" src="https://img.ljcdn.com/beike/zjz/bruno/img/1638883523735.jpg">
  </a>
</p>



<h1 align="center">Bruno</h1>
<div align="center">

An enterprise-class package of Flutter components for mobile applications.

[![license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/LianjiaTech/bruno/blob/master/LICENSE)

</div>

<div align="center">

 [简体中文](./README.md) | English

</div>



![](https://img.ljcdn.com/beike/zjz/bruno/img/1638883534391.png)

#### New components :tada: :tada: :tada:

<code>BrnSwitchButton</code>  <code>BrnSwitchFormItem</code>  <code>BrnGeneralFormItem</code>

 <img src="https://img.ljcdn.com/beike/zjz/bruno/img/1651141461442.png" width="300" height="359" />

## ✨ Features

* Enterprise-class UI designed for mobile applications.
* A set of high-quality Flutter components out of the box.
* Provides the ability to customize theme for different businesses
* Design tools to improve the efficiency of all participants

### Demo download

- The latest Demo download link: https://github.com/LianjiaTech/bruno/releases



## Adapted version of Flutter


| Bruno Version | Flutter SDK Version |
| ---------- | ---------------- |
| 1.0.0      | 1.22.4           |
| 2.0.0      | 2.2.2            |
| 2.1.1 (support nullsafety)      | 2.2.2            |
| 2.2.0 | 2.10.5 |


## Preparing for use

Add the following dependencies to the `pubspec.yaml` file:

```dart
dependencies:
  bruno: version
```

## Simple usage

```dart
import 'package:bruno/bruno.dart';
...
BrnBubbleText(
  maxLines: 3,
  text: 'I am first bubble text',
)
```

### 🌈 Customize themes

Reference [custom theme](https://bruno.ke.com/page/guide/theme).



## Contributing

Please read our [Contributing](https://bruno.ke.com/page/guide/contribution) first.

Thanks to all the developers who contributed to Bruno !

<div style="display:flex;flex-wrap: wrap;">
  <a href="https://github.com/violinday">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664602.png' />
  </a>
  <a href="https://github.com/zhoujuanjuan">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664928.png' />
  </a>
  <a href="https://github.com/hexintao">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664290.png' />
  </a>
  <a href="https://github.com/ShzMinato">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664590.png'  />
  </a>
  <a href="https://github.com/Nayuta403">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664273.png' />
  </a>
  <a href="https://github.com/liroya2003">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637736846398.png' />
  </a>
  <a href="https://github.com/lifuqing">
      <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664429.png' />
  </a>
  <a href="https://github.com/visitorvisit">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664282.png'  />
  </a>
  <a href="https://github.com/DNACore">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664426.png' />
  </a>
  <a href="https://github.com/SlamDunk007">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664914.png' />
  </a>
  <a href="https://github.com/zadouyoune">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664629.png' />
  </a>
  <a href="https://github.com/quanGitHub1">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664641.png'  />
  </a>
  <a href="https://github.com/bill19">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664536.png' />
  </a>
  <a href="https://github.com/MichaelWon">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664633.png' />
  </a>
  <a href="https://github.com/laoshubuluo">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664320.png' />
  </a>
  <a href="https://github.com/eason-lz">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664460.png' />
  </a>
  <a href="https://github.com/coolsining">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664465.png'  />
  </a>
  <a href="https://github.com/765227120">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637740374486.png' />
  </a>
  <a href="https://github.com/xzj524">
    <img src='https://img.ljcdn.com/beike/zjz/bruno/img/1637739664906.png' />
  </a>
  </div>



## 🔗 Links

- [Homepage](https://bruno.ke.com)
- [All component ](https://bruno.ke.com/page/widgets)
- [Design concept](https://mp.weixin.qq.com/s?__biz=MzIyODcxODY0OA==&mid=2247486048&idx=1&sn=0cc95bd85a54ce0f39f6247d15618ae8&chksm=e84ceb37df3b62216b34c7be041229630eca3d7c4fd3823ebf0520a9f2c99ed2cdf3e677904b&mpshare=1&scene=1&srcid=11012tvWvcYunVGfiPa8EfCT&sharer_sharetime=1635751229200&sharer_shareid=dbde8f595d5b99a8f5cfb27122964615&version=3.1.16.90294)
- [Preparing for use ](https://bruno.ke.com/page/guide/start)
- [Customize themes](https://bruno.ke.com/page/guide/theme)
- [Frequently asked question](https://bruno.ke.com/page/guide/faq)
- [Sketch usage](https://bruno.ke.com/page/guide/sketch)
- [Download of Design](https://bruno.ke.com/download/sketch)

## Acknowledgements

As a complete set of standard components, Bruno references the open source packages:

- [flutter_gifimage](https://github.com/peng8350/flutter_gifimage)
- [expansion_tile_card.dart](https://gist.github.com/Skylled/7ac0f2f99881f7df2a0a850e60ef2df0)
- [photo_view](https://github.com/bluefireteam/photo_view)
- [flutter_intro](https://github.com/tal-tech/flutter_intro)
- [flutter_badges](https://github.com/yako-dev/flutter_badges)
- [lpinyin](https://github.com/flutterchina/lpinyin)
- [azlistview](https://github.com/flutterchina/azlistview)
- [flutter_path_drawing](https://github.com/dnfield/flutter_path_drawing)

Thanks to the authors above.
